# NOTE: app info
__version__ = "0.2.8"
__description__ = """PyThermoDB Settings is a Python package that acts as an interface between pythermdb and other applications, providing robust, Pydantic-based data models and configuration structures for managing thermodynamic database (ThermoDB) settings."""
__author__ = "Sina Gilassi"
__author_email__ = "sina.gilassi@gmail.com"
