# export
from .configs.about import (
    __version__,
    __description__,
    __author__,
    __author_email__,
)

__all__ = [
    "__version__",
    "__description__",
    "__author__",
    "__author_email__",
]
